<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Pennsylvania";
    var qsoPartyUrl = "http://www.nittany-arc.net/PAQSO.html";
    var overlayUrl = "http://www.no5w.com/OverlayPennsylvaniaRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Adams", "ada");
  countySelection.options[1] = new Option("Allegheny", "all");
  countySelection.options[2] = new Option("Armstrong", "arm");
  countySelection.options[3] = new Option("Beaver", "bea");
  countySelection.options[4] = new Option("Bedford", "bed");
  countySelection.options[5] = new Option("Berks", "ber");
  countySelection.options[6] = new Option("Blair", "bla");
  countySelection.options[7] = new Option("Bradford", "bra");
  countySelection.options[8] = new Option("Bucks", "bux");
  countySelection.options[9] = new Option("Butler", "but");
  countySelection.options[10] = new Option("Cambria", "cmb");
  countySelection.options[11] = new Option("Cameron", "crn");
  countySelection.options[12] = new Option("Carbon", "car");
  countySelection.options[13] = new Option("Centre", "cen");
  countySelection.options[14] = new Option("Chester", "che");
  countySelection.options[15] = new Option("Clarion", "cla");
  countySelection.options[16] = new Option("Clearfield", "cle");
  countySelection.options[17] = new Option("Clinton", "cli");
  countySelection.options[18] = new Option("Columbia", "col");
  countySelection.options[19] = new Option("Crawford", "cra");
  countySelection.options[20] = new Option("Cumberland", "cum");
  countySelection.options[21] = new Option("Dauphin", "dau");
  countySelection.options[22] = new Option("Delaware", "dco");
  countySelection.options[23] = new Option("Elk", "elk");
  countySelection.options[24] = new Option("Erie", "eri");
  countySelection.options[25] = new Option("Fayette", "fay");
  countySelection.options[26] = new Option("Forest", "for");
  countySelection.options[27] = new Option("Franklin", "fra");
  countySelection.options[28] = new Option("Fulton", "ful");
  countySelection.options[29] = new Option("Greene", "gre");
  countySelection.options[30] = new Option("Huntingdon", "hun");
  countySelection.options[31] = new Option("Indiana", "inn");
  countySelection.options[32] = new Option("Jefferson", "jef");
  countySelection.options[33] = new Option("Juniata", "jun");
  countySelection.options[34] = new Option("Lackawanna", "lac");
  countySelection.options[35] = new Option("Lancaster", "lan");
  countySelection.options[36] = new Option("Lawrence", "law");
  countySelection.options[37] = new Option("Lebanon", "leb");
  countySelection.options[38] = new Option("Lehigh", "leh");
  countySelection.options[39] = new Option("Luzerne", "luz");
  countySelection.options[40] = new Option("Lycoming", "lyc");
  countySelection.options[41] = new Option("McKean", "mck");
  countySelection.options[42] = new Option("Mercer", "mer");
  countySelection.options[43] = new Option("Mifflin", "mif");
  countySelection.options[44] = new Option("Monroe", "moe");
  countySelection.options[45] = new Option("Montgomery", "mgy");
  countySelection.options[46] = new Option("Montour", "mtr");
  countySelection.options[47] = new Option("Northampton", "nha");
  countySelection.options[48] = new Option("Northumberland", "num");
  countySelection.options[49] = new Option("Perry", "per");
  countySelection.options[50] = new Option("Philadelphia", "phi");
  countySelection.options[51] = new Option("Pike", "pik");
  countySelection.options[52] = new Option("Potter", "pot");
  countySelection.options[53] = new Option("Schuylkill", "sch");
  countySelection.options[54] = new Option("Snyder", "sny");
  countySelection.options[55] = new Option("Somerset", "som");
  countySelection.options[56] = new Option("Sullivan", "sul");
  countySelection.options[57] = new Option("Susquehanna", "sus");
  countySelection.options[58] = new Option("Tioga", "tio");
  countySelection.options[59] = new Option("Union", "uni");
  countySelection.options[60] = new Option("Venango", "ven");
  countySelection.options[61] = new Option("Warren", "war");
  countySelection.options[62] = new Option("Washington", "was");
  countySelection.options[63] = new Option("Wayne", "way");
  countySelection.options[64] = new Option("Westmoreland", "wes");
  countySelection.options[65] = new Option("Wyoming", "wyo");
  countySelection.options[66] = new Option("York", "yor");
  addMarker(39.89480000, -77.21350000, "Adams", "ada");
  addMarker(40.43450000, -80.02490000, "Allegheny", "all");
  addMarker(40.84780000, -79.45160000, "Armstrong", "arm");
  addMarker(40.66620000, -80.33200000, "Beaver", "bea");
  addMarker(40.02480000, -78.47150000, "Bedford", "bed");
  addMarker(40.40720000, -75.98490000, "Berks", "ber");
  addMarker(40.49340000, -78.36820000, "Blair", "bla");
  addMarker(41.77190000, -76.52130000, "Bradford", "bra");
  addMarker(40.32860000, -75.10280000, "Bucks", "bux");
  addMarker(40.92110000, -79.92760000, "Butler", "but");
  addMarker(40.48450000, -78.70320000, "Cambria", "cmb");
  addMarker(41.41760000, -78.20500000, "Cameron", "crn");
  addMarker(40.93470000, -75.73580000, "Carbon", "car");
  addMarker(40.97220000, -77.75920000, "Centre", "cen");
  addMarker(39.98320000, -75.74810000, "Chester", "che");
  addMarker(41.20230000, -79.45370000, "Clarion", "cla");
  addMarker(40.98920000, -78.42230000, "Clearfield", "cle");
  addMarker(41.22060000, -77.61850000, "Clinton", "cli");
  addMarker(41.04210000, -76.42430000, "Columbia", "col");
  addMarker(41.66600000, -80.06570000, "Crawford", "cra");
  addMarker(40.13670000, -77.24280000, "Cumberland", "cum");
  addMarker(40.38990000, -76.78220000, "Dauphin", "dau");
  addMarker(39.93390000, -75.40600000, "Delaware", "dco");
  addMarker(41.41590000, -78.66510000, "Elk", "elk");
  addMarker(42.05960000, -80.06470000, "Erie", "eri");
  addMarker(39.93210000, -79.65220000, "Fayette", "fay");
  addMarker(41.47590000, -79.23910000, "Forest", "for");
  addMarker(40.00490000, -77.77630000, "Franklin", "fra");
  addMarker(39.94380000, -78.12240000, "Fulton", "ful");
  addMarker(39.87070000, -80.21130000, "Greene", "gre");
  addMarker(40.40260000, -77.96700000, "Huntingdon", "hun");
  addMarker(40.64010000, -79.12940000, "Indiana", "inn");
  addMarker(41.14110000, -78.96290000, "Jefferson", "jef");
  addMarker(40.47870000, -77.34550000, "Juniata", "jun");
  addMarker(41.40200000, -75.63760000, "Lackawanna", "lac");
  addMarker(40.01850000, -76.29760000, "Lancaster", "lan");
  addMarker(40.98960000, -80.30840000, "Lawrence", "law");
  addMarker(40.37540000, -76.41480000, "Lebanon", "leb");
  addMarker(40.60290000, -75.61270000, "Lehigh", "leh");
  addMarker(41.16460000, -75.96020000, "Luzerne", "luz");
  addMarker(41.33280000, -77.02360000, "Lycoming", "lyc");
  addMarker(41.80100000, -78.57970000, "McKean", "mck");
  addMarker(41.28110000, -80.25960000, "Mercer", "mer");
  addMarker(40.60390000, -77.60100000, "Mifflin", "mif");
  addMarker(41.03380000, -75.30800000, "Monroe", "moe");
  addMarker(40.21190000, -75.35590000, "Montgomery", "mgy");
  addMarker(41.02730000, -76.65350000, "Montour", "mtr");
  addMarker(40.75260000, -75.32990000, "Northampton", "nha");
  addMarker(40.88960000, -76.66460000, "Northumberland", "num");
  addMarker(40.40680000, -77.29260000, "Perry", "per");
  addMarker(40.00180000, -75.11790000, "Philadelphia", "phi");
  addMarker(41.34190000, -75.02410000, "Pike", "pik");
  addMarker(41.73760000, -77.90240000, "Potter", "pot");
  addMarker(40.72270000, -76.22960000, "Schuylkill", "sch");
  addMarker(40.76270000, -77.07750000, "Snyder", "sny");
  addMarker(40.00340000, -79.03800000, "Somerset", "som");
  addMarker(41.43290000, -76.51690000, "Sullivan", "sul");
  addMarker(41.82030000, -75.80460000, "Susquehanna", "sus");
  addMarker(41.77200000, -77.24220000, "Tioga", "tio");
  addMarker(40.97810000, -77.08180000, "Union", "uni");
  addMarker(41.39810000, -79.73880000, "Venango", "ven");
  addMarker(41.81170000, -79.26430000, "Warren", "war");
  addMarker(40.21490000, -80.17910000, "Washington", "was");
  addMarker(41.61600000, -75.27470000, "Wayne", "way");
  addMarker(40.36020000, -79.43980000, "Westmoreland", "wes");
  addMarker(41.51470000, -76.00070000, "Wyoming", "wyo");
  addMarker(39.97300000, -76.68780000, "York", "yor");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

